@@ -352,6 +352,24 @@ def any_fn(fn, coll):
     return False
 
 
+@curry(2)
+def all_pass(fx, x):
+    for fn in fx:
+        if not fn(x):
+            return False
+
+    return True
+
+
+@curry(2)
+def any_pass(fx, x):
+    for fn in fx:
+        if fn(x):
+            return True
+
+    return False
+
+
 @curry(2)
 def none(fn, coll):
     for x in coll:
